@@ -562,7 +562,7 @@ fn compare(expected: Option<&Path>, actual: &[u8], desc: &str) -> bool {
                 Err(e) => {
                     eprintln!(
                         "failed to open {} file: {}\n\
-                         -------- actual {0} --------\n\
+                         -------- normalized actual {0} --------\n\
                          {}",
                         desc,
                         e,
@@ -604,8 +604,8 @@ fn compare(expected: Option<&Path>, actual: &[u8], desc: &str) -> bool {
                     if output.stdout.is_empty() {
                         eprintln!(
                         "error: command {} mismatched, but unfortunately a diff can't be provided; \
-                         here is the actual output in bytes anyway: {:?}; \
-                         that's expected to match {:?}",
+                         here is the normalized actual output in bytes anyway: {:?} \
+                         (it's expected to match file {:?})",
                         desc, actual, expected
                     );
                     } else {
@@ -632,7 +632,7 @@ fn compare(expected: Option<&Path>, actual: &[u8], desc: &str) -> bool {
         }
     } else if !actual.is_empty() {
         eprintln!(
-            "error: expected the command to have empty {}, but it printed this:\n{}",
+            "error: expected the command to have empty {}, but it printed this (normalized):\n{}",
             desc,
             display_utf8_lossy(actual)
         );
@@ -714,7 +714,7 @@ impl CommandExt for Command {
 
 #[cfg(test)]
 mod tests {
-    use super::{CommandExt, Normalizer, OutputStr};
+    use super::{normalize, CommandExt, Normalizer, OutputStr};
     use std::{env::consts, path::Path, process::Command, str};
 
     #[test]
@@ -727,7 +727,7 @@ mod tests {
     }
 
     fn strip_exe() -> impl Normalizer {
-        super::normalize::stderr(|output| {
+        normalize::stderr(|output| {
             *output = str::from_utf8(output)
                 .unwrap()
                 .replace(consts::EXE_SUFFIX, "")
@@ -746,7 +746,7 @@ mod tests {
                 strip_exe(),
             );
         } else {
-            cargo.run_pass(OutputStr::empty(), super::normalize::noop());
+            cargo.run_pass(OutputStr::empty(), normalize::noop());
         }
     }
 
@@ -759,7 +759,7 @@ mod tests {
     }
 
     fn trim_final_newline() -> impl Normalizer {
-        super::normalize::stderr(|output| {
+        normalize::stderr(|output| {
             output.pop().unwrap();
             output
         })
@@ -773,14 +773,25 @@ mod tests {
         );
     }
 
+    fn rustdoc_command() -> Command {
+        let mut rustdoc = Command::rustdoc();
+        rustdoc.arg("--target=");
+        rustdoc
+    }
+
     #[test]
     fn rustdoc_target() {
-        Command::rustdoc().arg("--target=").run_fail(
+        rustdoc_command().run_fail(
             OutputStr::stderr_only("tests/ui/target.stderr"),
             trim_final_newline(),
         );
     }
 
+    #[test]
+    fn rustdoc_fake_empty() {
+        rustdoc_command().run_fail(OutputStr::empty(), normalize::stderr(|_| &[]));
+    }
+
     #[test]
     fn clippy_target() {
         Command::new("clippy-driver")
